# Modified Denavit–Hartenberg (mdh)

[![Actions Status](https://github.com/MultipedRobotics/dh/workflows/CheckPackage/badge.svg)](https://github.com/MultipedRobotics/dh/actions)
![GitHub](https://img.shields.io/github/license/multipedrobotics/dh)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mdh)
![PyPI](https://img.shields.io/pypi/v/mdh)


<img src="https://upload.wikimedia.org/wikipedia/commons/d/d8/DHParameter.png" width="600px">

[Modified Denavit-Hartenberg parameters](https://en.wikipedia.org/wiki/Denavit%E2%80%93Hartenberg_parameters#Modified_DH_parameters)

## Inspiration

You should probably use one of these, they inspired me to write a simpler
module for my needs:

- [pybotics](https://github.com/nnadeau/pybotics)
- [pytransform3d](https://github.com/rock-learning/pytransform3d)
